SPDCalc API
===========

Crystals
--------

See the list of :doc:`crystals`. To specify a custom crystal, see :any:`spdcalc.SPDC.crystal_kind`.

.. automodapi:: spdcalc.spdcalc
  :include-all-objects:
  :no-inherited-members:
  :no-inheritance-diagram:
